@@ -1,5 +1,6 @@
 #!/bin/bash
 
+aembit_raw_prerouting_chain_name=aembit_raw_prerouting_chain
 aembit_raw_output_chain_name=aembit_raw_output_chain
 aembit_nat_output_chain_name=aembit_nat_output_chain
 aembit_nat_prerouting_chain_name=aembit_nat_prerouting_chain
@@ -61,6 +62,12 @@ iptables -t raw -A "${aembit_raw_output_chain_name}" -p udp -s 127.0.0.53 --spor
 # Add chain
 iptables -t raw -A OUTPUT -j "${aembit_raw_output_chain_name}"
 
+# ----- aembit_raw_prerouting_chain -----
+
+iptables -t raw -N "${aembit_raw_prerouting_chain_name}"
+iptables -t raw -A "${aembit_raw_prerouting_chain_name}" -p udp --sport 53 -j NOTRACK
+iptables -t raw -A PREROUTING -j "${aembit_raw_prerouting_chain_name}"
+
 # ----- aembit_nat_output_chain ------
 
 # Create chain
